@@ -1,43 +1,60 @@
-//  ---------------------------------------------------------------------
-//  This file is part of Brahe, a heterogenous library of mathematical
-//  and scientific functions written in C.
-//
-//  Brahe may be licensed either under the GNU General Public License v3
-//  or a closed license from the author. See below for more information.
-//
-//  prng.c
-//
-//  Psuedorandom number generators
-//
-//  Copyright 2006, 2007, 2009 Scott Robert Ladd
-//  ---------------------------------------------------------------------
-//
-//  Brahe is free software: you can redistribute it and/or modify
-//  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation, either version 3 of the License, or
-//  (at your option) any later version.
-//
-//  This program is distributed in the hope that it will be useful,
-//  but WITHOUT ANY WARRANTY; without even the implied warranty of
-//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-//  GNU General Public License for more details.
-//
-//  You should have received a copy of the GNU General Public License
-//  along with this program.  If not, see <http://www.gnu.org/licenses/>.
-//
-//  ---------------------------------------------------------------------
-//  Closed-source licenses are available from the author at reasonable
-//  prices.
-//  ---------------------------------------------------------------------
-//  
-//  For more information on this software package, please visit
-//  Scott's web site, Coyote Gulch Productions, at:
-//
-//      http://www.coyotegulch.com
+/*
+    Brahe is a heterogenous collection of mathematical tools,  written in Standard C.
+
+    Copyright 2011 Scott Robert Ladd. All rights reserved.
+
+    Brahe is user-supported open source software. Its continued development is dependent
+    on financial support from the community. You can provide funding by visiting the Brahe
+    website at:
+
+        http://www.coyotegulch.com
+
+    You may license Brahe in one of two fashions:
+
+    1) Simplified BSD License (FreeBSD License)
+
+    Redistribution and use in source and binary forms, with or without modification, are
+    permitted provided that the following conditions are met:
+
+    1.  Redistributions of source code must retain the above copyright notice, this list of
+        conditions and the following disclaimer.
+
+    2.  Redistributions in binary form must reproduce the above copyright notice, this list
+        of conditions and the following disclaimer in the documentation and/or other materials
+        provided with the distribution.
+
+    THIS SOFTWARE IS PROVIDED BY SCOTT ROBERT LADD ``AS IS'' AND ANY EXPRESS OR IMPLIED
+    WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
+    FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL SCOTT ROBERT LADD OR
+    CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+    CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
+    SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
+    ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
+    NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
+    ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+
+    The views and conclusions contained in the software and documentation are those of the
+    authors and should not be interpreted as representing official policies, either expressed
+    or implied, of Scott Robert Ladd.
+
+    2) Closed-Source Proprietary License
+
+    If your project is a closed-source or proprietary project, the Simplified BSD License may
+    not be appropriate or desirable. In such cases, contact the Brahe copyright holder to
+    arrange your purchase of an appropriate license.
+
+    The author can be contacted at:
+
+          scott.ladd@coyotegulch.com
+          scott.ladd@gmail.com
+          http:www.coyotegulch.com
+*/
 
 #include "prng.h"
 
-#if !defined(_MSC_VER)
+#if defined(_MSC_VER)
+#pragma warning (disable: 4996)
+#else
 #include <unistd.h>
 #include <fcntl.h>
 #endif
@@ -129,7 +146,7 @@ static uint32_t mtwister_next(brahe_prng_state_t * prng_state)
             prng_state->m_i = 0;
         }
 
-        // Here is where we actually calculate the number with a series of transformations 
+        // Here is where we actually calculate the number with a series of transformations
         result = m[prng_state->m_i++];
 
         result ^= (result >> 11);
@@ -390,7 +407,7 @@ static bool isaac_init(brahe_prng_state_t * prng_state)
         prng_state->m_b = 0;
         prng_state->m_c = 0;
         prng_state->m_i = 0;
-            
+
         prng_state->m_data1 = malloc(sizeof(uint32_t) * 256);
 
         if (prng_state->m_data1 != NULL)
@@ -512,12 +529,14 @@ bool brahe_prng_init(brahe_prng_state_t * prng_state, const brahe_prng_type_t ty
             if (fd != -1)
             {
                 uint32_t s = 0;
-                
+
                 int n = read(fd, &s, 4);
                 close(fd);
-                
-                if (n != sizeof(uint32_t))
+
+                if (n == sizeof(uint32_t))
                     prng_state->m_seed = s;
+                else
+                    prng_state->m_seed = (uint32_t)time(NULL);
             }
 #endif
         }
@@ -609,7 +628,7 @@ uint32_t brahe_prng_range(brahe_prng_state_t * prng_state, const uint32_t lo, co
 }
 
 // Get the next random value as a size_t index
-size_t brahe_prng_index(brahe_prng_state_t * prng_state, size_t length)
+size_t brahe_prng_index(brahe_prng_state_t * prng_state, const size_t length)
 {
     return (size_t)((double)length * brahe_prng_real2(prng_state));
 }
